@@ -180,6 +180,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -232,18 +233,18 @@ instance B.Types.TypedObject AssistantPage where
 
 instance B.Types.GObject AssistantPage
 
--- | Type class for types which can be safely cast to `AssistantPage`, for instance with `toAssistantPage`.
+-- | Type class for types which can be safely cast to t'AssistantPage', for instance with `toAssistantPage`.
 class (SP.GObject o, O.IsDescendantOf AssistantPage o) => IsAssistantPage o
 instance (SP.GObject o, O.IsDescendantOf AssistantPage o) => IsAssistantPage o
 
 instance O.HasParentTypes AssistantPage
 type instance O.ParentTypes AssistantPage = '[GObject.Object.Object]
 
--- | Cast to `AssistantPage`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'AssistantPage', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toAssistantPage :: (MIO.MonadIO m, IsAssistantPage o) => o -> m AssistantPage
 toAssistantPage = MIO.liftIO . B.ManagedPtr.unsafeCastTo AssistantPage
 
--- | Convert 'AssistantPage' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'AssistantPage' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe AssistantPage) where
     gvalueGType_ = c_gtk_assistant_page_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr AssistantPage)
@@ -319,7 +320,7 @@ instance (info ~ ResolveAssistantPageMethod t AssistantPage, O.OverloadedMethodI
 getAssistantPageChild :: (MonadIO m, IsAssistantPage o) => o -> m Gtk.Widget.Widget
 getAssistantPageChild obj = MIO.liftIO $ checkUnexpectedNothing "getAssistantPageChild" $ B.Properties.getObjectPropertyObject obj "child" Gtk.Widget.Widget
 
--- | Construct a `GValueConstruct` with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructAssistantPageChild :: (IsAssistantPage o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructAssistantPageChild val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child" (P.Just val)
@@ -343,7 +344,7 @@ instance AttrInfo AssistantPageChildPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.AssistantPage.child"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:child"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:child"
         })
 #endif
 
@@ -371,7 +372,7 @@ setAssistantPageComplete :: (MonadIO m, IsAssistantPage o) => o -> Bool -> m ()
 setAssistantPageComplete obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "complete" val
 
--- | Construct a `GValueConstruct` with valid value for the “@complete@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@complete@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructAssistantPageComplete :: (IsAssistantPage o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructAssistantPageComplete val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "complete" val
@@ -395,7 +396,7 @@ instance AttrInfo AssistantPageCompletePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.AssistantPage.complete"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:complete"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:complete"
         })
 #endif
 
@@ -423,7 +424,7 @@ setAssistantPagePageType :: (MonadIO m, IsAssistantPage o) => o -> Gtk.Enums.Ass
 setAssistantPagePageType obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyEnum obj "page-type" val
 
--- | Construct a `GValueConstruct` with valid value for the “@page-type@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@page-type@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructAssistantPagePageType :: (IsAssistantPage o, MIO.MonadIO m) => Gtk.Enums.AssistantPageType -> m (GValueConstruct o)
 constructAssistantPagePageType val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyEnum "page-type" val
@@ -447,7 +448,7 @@ instance AttrInfo AssistantPagePageTypePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.AssistantPage.pageType"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:pageType"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:pageType"
         })
 #endif
 
@@ -475,7 +476,7 @@ setAssistantPageTitle :: (MonadIO m, IsAssistantPage o) => o -> T.Text -> m ()
 setAssistantPageTitle obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyString obj "title" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@title@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@title@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructAssistantPageTitle :: (IsAssistantPage o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructAssistantPageTitle val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "title" (P.Just val)
@@ -508,7 +509,7 @@ instance AttrInfo AssistantPageTitlePropertyInfo where
     attrClear = clearAssistantPageTitle
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.AssistantPage.title"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:title"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AssistantPage.html#g:attr:title"
         })
 #endif
 
@@ -593,7 +594,7 @@ instance (signature ~ (m Gtk.Widget.Widget), MonadIO m, IsAssistantPage a) => O.
 instance O.OverloadedMethodInfo AssistantPageGetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.AssistantPage.assistantPageGetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-AssistantPage.html#v:assistantPageGetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-AssistantPage.html#v:assistantPageGetChild"
         })
 
 
