@@ -143,6 +143,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -195,18 +196,18 @@ instance B.Types.TypedObject FixedLayoutChild where
 
 instance B.Types.GObject FixedLayoutChild
 
--- | Type class for types which can be safely cast to `FixedLayoutChild`, for instance with `toFixedLayoutChild`.
+-- | Type class for types which can be safely cast to t'FixedLayoutChild', for instance with `toFixedLayoutChild`.
 class (SP.GObject o, O.IsDescendantOf FixedLayoutChild o) => IsFixedLayoutChild o
 instance (SP.GObject o, O.IsDescendantOf FixedLayoutChild o) => IsFixedLayoutChild o
 
 instance O.HasParentTypes FixedLayoutChild
 type instance O.ParentTypes FixedLayoutChild = '[Gtk.LayoutChild.LayoutChild, GObject.Object.Object]
 
--- | Cast to `FixedLayoutChild`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'FixedLayoutChild', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toFixedLayoutChild :: (MIO.MonadIO m, IsFixedLayoutChild o) => o -> m FixedLayoutChild
 toFixedLayoutChild = MIO.liftIO . B.ManagedPtr.unsafeCastTo FixedLayoutChild
 
--- | Convert 'FixedLayoutChild' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'FixedLayoutChild' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe FixedLayoutChild) where
     gvalueGType_ = c_gtk_fixed_layout_child_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr FixedLayoutChild)
@@ -295,7 +296,7 @@ setFixedLayoutChildTransform :: (MonadIO m, IsFixedLayoutChild o) => o -> Gsk.Tr
 setFixedLayoutChildTransform obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBoxed obj "transform" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@transform@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@transform@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructFixedLayoutChildTransform :: (IsFixedLayoutChild o, MIO.MonadIO m) => Gsk.Transform.Transform -> m (GValueConstruct o)
 constructFixedLayoutChildTransform val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBoxed "transform" (P.Just val)
@@ -319,7 +320,7 @@ instance AttrInfo FixedLayoutChildTransformPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.FixedLayoutChild.transform"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-FixedLayoutChild.html#g:attr:transform"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-FixedLayoutChild.html#g:attr:transform"
         })
 #endif
 
@@ -395,7 +396,7 @@ instance (signature ~ (m (Maybe Gsk.Transform.Transform)), MonadIO m, IsFixedLay
 instance O.OverloadedMethodInfo FixedLayoutChildGetTransformMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.FixedLayoutChild.fixedLayoutChildGetTransform",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-FixedLayoutChild.html#v:fixedLayoutChildGetTransform"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-FixedLayoutChild.html#v:fixedLayoutChildGetTransform"
         })
 
 
@@ -472,7 +473,7 @@ instance (signature ~ (Gsk.Transform.Transform -> m ()), MonadIO m, IsFixedLayou
 instance O.OverloadedMethodInfo FixedLayoutChildSetTransformMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.FixedLayoutChild.fixedLayoutChildSetTransform",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-FixedLayoutChild.html#v:fixedLayoutChildSetTransform"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-FixedLayoutChild.html#v:fixedLayoutChildSetTransform"
         })
 
 
