@@ -162,6 +162,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -213,18 +214,18 @@ instance B.Types.TypedObject LayoutChild where
 
 instance B.Types.GObject LayoutChild
 
--- | Type class for types which can be safely cast to `LayoutChild`, for instance with `toLayoutChild`.
+-- | Type class for types which can be safely cast to t'LayoutChild', for instance with `toLayoutChild`.
 class (SP.GObject o, O.IsDescendantOf LayoutChild o) => IsLayoutChild o
 instance (SP.GObject o, O.IsDescendantOf LayoutChild o) => IsLayoutChild o
 
 instance O.HasParentTypes LayoutChild
 type instance O.ParentTypes LayoutChild = '[GObject.Object.Object]
 
--- | Cast to `LayoutChild`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'LayoutChild', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toLayoutChild :: (MIO.MonadIO m, IsLayoutChild o) => o -> m LayoutChild
 toLayoutChild = MIO.liftIO . B.ManagedPtr.unsafeCastTo LayoutChild
 
--- | Convert 'LayoutChild' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'LayoutChild' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe LayoutChild) where
     gvalueGType_ = c_gtk_layout_child_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr LayoutChild)
@@ -301,7 +302,7 @@ instance (info ~ ResolveLayoutChildMethod t LayoutChild, O.OverloadedMethodInfo
 getLayoutChildChildWidget :: (MonadIO m, IsLayoutChild o) => o -> m Gtk.Widget.Widget
 getLayoutChildChildWidget obj = MIO.liftIO $ checkUnexpectedNothing "getLayoutChildChildWidget" $ B.Properties.getObjectPropertyObject obj "child-widget" Gtk.Widget.Widget
 
--- | Construct a `GValueConstruct` with valid value for the “@child-widget@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child-widget@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructLayoutChildChildWidget :: (IsLayoutChild o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructLayoutChildChildWidget val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child-widget" (P.Just val)
@@ -325,7 +326,7 @@ instance AttrInfo LayoutChildChildWidgetPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.LayoutChild.childWidget"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-LayoutChild.html#g:attr:childWidget"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-LayoutChild.html#g:attr:childWidget"
         })
 #endif
 
@@ -343,7 +344,7 @@ instance AttrInfo LayoutChildChildWidgetPropertyInfo where
 getLayoutChildLayoutManager :: (MonadIO m, IsLayoutChild o) => o -> m Gtk.LayoutManager.LayoutManager
 getLayoutChildLayoutManager obj = MIO.liftIO $ checkUnexpectedNothing "getLayoutChildLayoutManager" $ B.Properties.getObjectPropertyObject obj "layout-manager" Gtk.LayoutManager.LayoutManager
 
--- | Construct a `GValueConstruct` with valid value for the “@layout-manager@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@layout-manager@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructLayoutChildLayoutManager :: (IsLayoutChild o, MIO.MonadIO m, Gtk.LayoutManager.IsLayoutManager a) => a -> m (GValueConstruct o)
 constructLayoutChildLayoutManager val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "layout-manager" (P.Just val)
@@ -367,7 +368,7 @@ instance AttrInfo LayoutChildLayoutManagerPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.LayoutChild.layoutManager"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-LayoutChild.html#g:attr:layoutManager"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-LayoutChild.html#g:attr:layoutManager"
         })
 #endif
 
@@ -443,7 +444,7 @@ instance (signature ~ (m Gtk.Widget.Widget), MonadIO m, IsLayoutChild a) => O.Ov
 instance O.OverloadedMethodInfo LayoutChildGetChildWidgetMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.LayoutChild.layoutChildGetChildWidget",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-LayoutChild.html#v:layoutChildGetChildWidget"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-LayoutChild.html#v:layoutChildGetChildWidget"
         })
 
 
@@ -502,7 +503,7 @@ instance (signature ~ (m Gtk.LayoutManager.LayoutManager), MonadIO m, IsLayoutCh
 instance O.OverloadedMethodInfo LayoutChildGetLayoutManagerMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.LayoutChild.layoutChildGetLayoutManager",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-LayoutChild.html#v:layoutChildGetLayoutManager"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-LayoutChild.html#v:layoutChildGetLayoutManager"
         })
 
 
