@@ -260,6 +260,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -311,18 +312,18 @@ instance B.Types.TypedObject NotebookPage where
 
 instance B.Types.GObject NotebookPage
 
--- | Type class for types which can be safely cast to `NotebookPage`, for instance with `toNotebookPage`.
+-- | Type class for types which can be safely cast to t'NotebookPage', for instance with `toNotebookPage`.
 class (SP.GObject o, O.IsDescendantOf NotebookPage o) => IsNotebookPage o
 instance (SP.GObject o, O.IsDescendantOf NotebookPage o) => IsNotebookPage o
 
 instance O.HasParentTypes NotebookPage
 type instance O.ParentTypes NotebookPage = '[GObject.Object.Object]
 
--- | Cast to `NotebookPage`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'NotebookPage', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toNotebookPage :: (MIO.MonadIO m, IsNotebookPage o) => o -> m NotebookPage
 toNotebookPage = MIO.liftIO . B.ManagedPtr.unsafeCastTo NotebookPage
 
--- | Convert 'NotebookPage' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'NotebookPage' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe NotebookPage) where
     gvalueGType_ = c_gtk_notebook_page_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr NotebookPage)
@@ -398,7 +399,7 @@ instance (info ~ ResolveNotebookPageMethod t NotebookPage, O.OverloadedMethodInf
 getNotebookPageChild :: (MonadIO m, IsNotebookPage o) => o -> m Gtk.Widget.Widget
 getNotebookPageChild obj = MIO.liftIO $ checkUnexpectedNothing "getNotebookPageChild" $ B.Properties.getObjectPropertyObject obj "child" Gtk.Widget.Widget
 
--- | Construct a `GValueConstruct` with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@child@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageChild :: (IsNotebookPage o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructNotebookPageChild val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "child" (P.Just val)
@@ -422,7 +423,7 @@ instance AttrInfo NotebookPageChildPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.child"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:child"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:child"
         })
 #endif
 
@@ -450,7 +451,7 @@ setNotebookPageDetachable :: (MonadIO m, IsNotebookPage o) => o -> Bool -> m ()
 setNotebookPageDetachable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "detachable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@detachable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@detachable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageDetachable :: (IsNotebookPage o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructNotebookPageDetachable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "detachable" val
@@ -474,7 +475,7 @@ instance AttrInfo NotebookPageDetachablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.detachable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:detachable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:detachable"
         })
 #endif
 
@@ -492,7 +493,7 @@ instance AttrInfo NotebookPageDetachablePropertyInfo where
 getNotebookPageMenu :: (MonadIO m, IsNotebookPage o) => o -> m (Maybe Gtk.Widget.Widget)
 getNotebookPageMenu obj = MIO.liftIO $ B.Properties.getObjectPropertyObject obj "menu" Gtk.Widget.Widget
 
--- | Construct a `GValueConstruct` with valid value for the “@menu@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@menu@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageMenu :: (IsNotebookPage o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructNotebookPageMenu val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "menu" (P.Just val)
@@ -516,7 +517,7 @@ instance AttrInfo NotebookPageMenuPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.menu"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:menu"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:menu"
         })
 #endif
 
@@ -544,7 +545,7 @@ setNotebookPageMenuLabel :: (MonadIO m, IsNotebookPage o) => o -> T.Text -> m ()
 setNotebookPageMenuLabel obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyString obj "menu-label" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@menu-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@menu-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageMenuLabel :: (IsNotebookPage o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructNotebookPageMenuLabel val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "menu-label" (P.Just val)
@@ -577,7 +578,7 @@ instance AttrInfo NotebookPageMenuLabelPropertyInfo where
     attrClear = clearNotebookPageMenuLabel
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.menuLabel"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:menuLabel"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:menuLabel"
         })
 #endif
 
@@ -605,7 +606,7 @@ setNotebookPagePosition :: (MonadIO m, IsNotebookPage o) => o -> Int32 -> m ()
 setNotebookPagePosition obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyInt32 obj "position" val
 
--- | Construct a `GValueConstruct` with valid value for the “@position@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@position@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPagePosition :: (IsNotebookPage o, MIO.MonadIO m) => Int32 -> m (GValueConstruct o)
 constructNotebookPagePosition val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyInt32 "position" val
@@ -629,7 +630,7 @@ instance AttrInfo NotebookPagePositionPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.position"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:position"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:position"
         })
 #endif
 
@@ -657,7 +658,7 @@ setNotebookPageReorderable :: (MonadIO m, IsNotebookPage o) => o -> Bool -> m ()
 setNotebookPageReorderable obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "reorderable" val
 
--- | Construct a `GValueConstruct` with valid value for the “@reorderable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@reorderable@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageReorderable :: (IsNotebookPage o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructNotebookPageReorderable val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "reorderable" val
@@ -681,7 +682,7 @@ instance AttrInfo NotebookPageReorderablePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.reorderable"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:reorderable"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:reorderable"
         })
 #endif
 
@@ -699,7 +700,7 @@ instance AttrInfo NotebookPageReorderablePropertyInfo where
 getNotebookPageTab :: (MonadIO m, IsNotebookPage o) => o -> m (Maybe Gtk.Widget.Widget)
 getNotebookPageTab obj = MIO.liftIO $ B.Properties.getObjectPropertyObject obj "tab" Gtk.Widget.Widget
 
--- | Construct a `GValueConstruct` with valid value for the “@tab@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@tab@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageTab :: (IsNotebookPage o, MIO.MonadIO m, Gtk.Widget.IsWidget a) => a -> m (GValueConstruct o)
 constructNotebookPageTab val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "tab" (P.Just val)
@@ -723,7 +724,7 @@ instance AttrInfo NotebookPageTabPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.tab"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tab"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tab"
         })
 #endif
 
@@ -751,7 +752,7 @@ setNotebookPageTabExpand :: (MonadIO m, IsNotebookPage o) => o -> Bool -> m ()
 setNotebookPageTabExpand obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "tab-expand" val
 
--- | Construct a `GValueConstruct` with valid value for the “@tab-expand@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@tab-expand@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageTabExpand :: (IsNotebookPage o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructNotebookPageTabExpand val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "tab-expand" val
@@ -775,7 +776,7 @@ instance AttrInfo NotebookPageTabExpandPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.tabExpand"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabExpand"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabExpand"
         })
 #endif
 
@@ -803,7 +804,7 @@ setNotebookPageTabFill :: (MonadIO m, IsNotebookPage o) => o -> Bool -> m ()
 setNotebookPageTabFill obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "tab-fill" val
 
--- | Construct a `GValueConstruct` with valid value for the “@tab-fill@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@tab-fill@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageTabFill :: (IsNotebookPage o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructNotebookPageTabFill val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "tab-fill" val
@@ -827,7 +828,7 @@ instance AttrInfo NotebookPageTabFillPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.tabFill"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabFill"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabFill"
         })
 #endif
 
@@ -855,7 +856,7 @@ setNotebookPageTabLabel :: (MonadIO m, IsNotebookPage o) => o -> T.Text -> m ()
 setNotebookPageTabLabel obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyString obj "tab-label" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@tab-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@tab-label@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructNotebookPageTabLabel :: (IsNotebookPage o, MIO.MonadIO m) => T.Text -> m (GValueConstruct o)
 constructNotebookPageTabLabel val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyString "tab-label" (P.Just val)
@@ -888,7 +889,7 @@ instance AttrInfo NotebookPageTabLabelPropertyInfo where
     attrClear = clearNotebookPageTabLabel
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.tabLabel"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabLabel"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#g:attr:tabLabel"
         })
 #endif
 
@@ -990,7 +991,7 @@ instance (signature ~ (m Gtk.Widget.Widget), MonadIO m, IsNotebookPage a) => O.O
 instance O.OverloadedMethodInfo NotebookPageGetChildMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.NotebookPage.notebookPageGetChild",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-NotebookPage.html#v:notebookPageGetChild"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-NotebookPage.html#v:notebookPageGetChild"
         })
 
 
