@@ -174,6 +174,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -225,18 +226,18 @@ instance B.Types.TypedObject OverlayLayoutChild where
 
 instance B.Types.GObject OverlayLayoutChild
 
--- | Type class for types which can be safely cast to `OverlayLayoutChild`, for instance with `toOverlayLayoutChild`.
+-- | Type class for types which can be safely cast to t'OverlayLayoutChild', for instance with `toOverlayLayoutChild`.
 class (SP.GObject o, O.IsDescendantOf OverlayLayoutChild o) => IsOverlayLayoutChild o
 instance (SP.GObject o, O.IsDescendantOf OverlayLayoutChild o) => IsOverlayLayoutChild o
 
 instance O.HasParentTypes OverlayLayoutChild
 type instance O.ParentTypes OverlayLayoutChild = '[Gtk.LayoutChild.LayoutChild, GObject.Object.Object]
 
--- | Cast to `OverlayLayoutChild`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'OverlayLayoutChild', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toOverlayLayoutChild :: (MIO.MonadIO m, IsOverlayLayoutChild o) => o -> m OverlayLayoutChild
 toOverlayLayoutChild = MIO.liftIO . B.ManagedPtr.unsafeCastTo OverlayLayoutChild
 
--- | Convert 'OverlayLayoutChild' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'OverlayLayoutChild' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe OverlayLayoutChild) where
     gvalueGType_ = c_gtk_overlay_layout_child_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr OverlayLayoutChild)
@@ -327,7 +328,7 @@ setOverlayLayoutChildClipOverlay :: (MonadIO m, IsOverlayLayoutChild o) => o ->
 setOverlayLayoutChildClipOverlay obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "clip-overlay" val
 
--- | Construct a `GValueConstruct` with valid value for the “@clip-overlay@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@clip-overlay@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructOverlayLayoutChildClipOverlay :: (IsOverlayLayoutChild o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructOverlayLayoutChildClipOverlay val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "clip-overlay" val
@@ -351,7 +352,7 @@ instance AttrInfo OverlayLayoutChildClipOverlayPropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.clipOverlay"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#g:attr:clipOverlay"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#g:attr:clipOverlay"
         })
 #endif
 
@@ -379,7 +380,7 @@ setOverlayLayoutChildMeasure :: (MonadIO m, IsOverlayLayoutChild o) => o -> Bool
 setOverlayLayoutChildMeasure obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyBool obj "measure" val
 
--- | Construct a `GValueConstruct` with valid value for the “@measure@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@measure@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructOverlayLayoutChildMeasure :: (IsOverlayLayoutChild o, MIO.MonadIO m) => Bool -> m (GValueConstruct o)
 constructOverlayLayoutChildMeasure val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyBool "measure" val
@@ -403,7 +404,7 @@ instance AttrInfo OverlayLayoutChildMeasurePropertyInfo where
     attrClear = undefined
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.measure"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#g:attr:measure"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#g:attr:measure"
         })
 #endif
 
@@ -480,7 +481,7 @@ instance (signature ~ (m Bool), MonadIO m, IsOverlayLayoutChild a) => O.Overload
 instance O.OverloadedMethodInfo OverlayLayoutChildGetClipOverlayMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.overlayLayoutChildGetClipOverlay",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildGetClipOverlay"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildGetClipOverlay"
         })
 
 
@@ -538,7 +539,7 @@ instance (signature ~ (m Bool), MonadIO m, IsOverlayLayoutChild a) => O.Overload
 instance O.OverloadedMethodInfo OverlayLayoutChildGetMeasureMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.overlayLayoutChildGetMeasure",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildGetMeasure"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildGetMeasure"
         })
 
 
@@ -615,7 +616,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsOverlayLayoutChild a) => O.Ov
 instance O.OverloadedMethodInfo OverlayLayoutChildSetClipOverlayMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.overlayLayoutChildSetClipOverlay",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildSetClipOverlay"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildSetClipOverlay"
         })
 
 
@@ -692,7 +693,7 @@ instance (signature ~ (Bool -> m ()), MonadIO m, IsOverlayLayoutChild a) => O.Ov
 instance O.OverloadedMethodInfo OverlayLayoutChildSetMeasureMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.OverlayLayoutChild.overlayLayoutChildSetMeasure",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildSetMeasure"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-OverlayLayoutChild.html#v:overlayLayoutChildSetMeasure"
         })
 
 
