@@ -227,6 +227,7 @@ import qualified GI.Gsk.Objects.GLShader as Gsk.GLShader
 import qualified GI.Gsk.Objects.RenderNode as Gsk.RenderNode
 import qualified GI.Gsk.Objects.Renderer as Gsk.Renderer
 import qualified GI.Gsk.Structs.ColorStop as Gsk.ColorStop
+import qualified GI.Gsk.Structs.ComponentTransfer as Gsk.ComponentTransfer
 import qualified GI.Gsk.Structs.Path as Gsk.Path
 import qualified GI.Gsk.Structs.RoundedRect as Gsk.RoundedRect
 import qualified GI.Gsk.Structs.Shadow as Gsk.Shadow
@@ -281,18 +282,18 @@ instance B.Types.TypedObject Shortcut where
 
 instance B.Types.GObject Shortcut
 
--- | Type class for types which can be safely cast to `Shortcut`, for instance with `toShortcut`.
+-- | Type class for types which can be safely cast to t'Shortcut', for instance with `toShortcut`.
 class (SP.GObject o, O.IsDescendantOf Shortcut o) => IsShortcut o
 instance (SP.GObject o, O.IsDescendantOf Shortcut o) => IsShortcut o
 
 instance O.HasParentTypes Shortcut
 type instance O.ParentTypes Shortcut = '[GObject.Object.Object]
 
--- | Cast to `Shortcut`, for types for which this is known to be safe. For general casts, use `Data.GI.Base.ManagedPtr.castTo`.
+-- | Cast to t'Shortcut', for types for which this is known to be safe. For general casts, use 'Data.GI.Base.ManagedPtr.castTo'.
 toShortcut :: (MIO.MonadIO m, IsShortcut o) => o -> m Shortcut
 toShortcut = MIO.liftIO . B.ManagedPtr.unsafeCastTo Shortcut
 
--- | Convert 'Shortcut' to and from 'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
+-- | Convert t'Shortcut' to and from t'Data.GI.Base.GValue.GValue'. See 'Data.GI.Base.GValue.toGValue' and 'Data.GI.Base.GValue.fromGValue'.
 instance B.GValue.IsGValue (Maybe Shortcut) where
     gvalueGType_ = c_gtk_shortcut_get_type
     gvalueSet_ gv P.Nothing = B.GValue.set_object gv (FP.nullPtr :: FP.Ptr Shortcut)
@@ -383,7 +384,7 @@ setShortcutAction :: (MonadIO m, IsShortcut o, Gtk.ShortcutAction.IsShortcutActi
 setShortcutAction obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyObject obj "action" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@action@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@action@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructShortcutAction :: (IsShortcut o, MIO.MonadIO m, Gtk.ShortcutAction.IsShortcutAction a) => a -> m (GValueConstruct o)
 constructShortcutAction val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "action" (P.Just val)
@@ -416,7 +417,7 @@ instance AttrInfo ShortcutActionPropertyInfo where
     attrClear = clearShortcutAction
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.action"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#g:attr:action"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#g:attr:action"
         })
 #endif
 
@@ -444,7 +445,7 @@ setShortcutArguments :: (MonadIO m, IsShortcut o) => o -> GVariant -> m ()
 setShortcutArguments obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyVariant obj "arguments" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@arguments@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@arguments@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructShortcutArguments :: (IsShortcut o, MIO.MonadIO m) => GVariant -> m (GValueConstruct o)
 constructShortcutArguments val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyVariant "arguments" (P.Just val)
@@ -477,7 +478,7 @@ instance AttrInfo ShortcutArgumentsPropertyInfo where
     attrClear = clearShortcutArguments
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.arguments"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#g:attr:arguments"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#g:attr:arguments"
         })
 #endif
 
@@ -505,7 +506,7 @@ setShortcutTrigger :: (MonadIO m, IsShortcut o, Gtk.ShortcutTrigger.IsShortcutTr
 setShortcutTrigger obj val = MIO.liftIO $ do
     B.Properties.setObjectPropertyObject obj "trigger" (Just val)
 
--- | Construct a `GValueConstruct` with valid value for the “@trigger@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
+-- | Construct a t'GValueConstruct' with valid value for the “@trigger@” property. This is rarely needed directly, but it is used by `Data.GI.Base.Constructible.new`.
 constructShortcutTrigger :: (IsShortcut o, MIO.MonadIO m, Gtk.ShortcutTrigger.IsShortcutTrigger a) => a -> m (GValueConstruct o)
 constructShortcutTrigger val = MIO.liftIO $ do
     MIO.liftIO $ B.Properties.constructObjectPropertyObject "trigger" (P.Just val)
@@ -538,7 +539,7 @@ instance AttrInfo ShortcutTriggerPropertyInfo where
     attrClear = clearShortcutTrigger
     dbgAttrInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.trigger"
-        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#g:attr:trigger"
+        , O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#g:attr:trigger"
         })
 #endif
 
@@ -701,7 +702,7 @@ instance (signature ~ (m (Maybe Gtk.ShortcutAction.ShortcutAction)), MonadIO m,
 instance O.OverloadedMethodInfo ShortcutGetActionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutGetAction",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetAction"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetAction"
         })
 
 
@@ -759,7 +760,7 @@ instance (signature ~ (m (Maybe GVariant)), MonadIO m, IsShortcut a) => O.Overlo
 instance O.OverloadedMethodInfo ShortcutGetArgumentsMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutGetArguments",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetArguments"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetArguments"
         })
 
 
@@ -818,7 +819,7 @@ instance (signature ~ (m (Maybe Gtk.ShortcutTrigger.ShortcutTrigger)), MonadIO m
 instance O.OverloadedMethodInfo ShortcutGetTriggerMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutGetTrigger",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetTrigger"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutGetTrigger"
         })
 
 
@@ -902,7 +903,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsShortcut a, Gtk.Shortcut
 instance O.OverloadedMethodInfo ShortcutSetActionMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutSetAction",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetAction"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetAction"
         })
 
 
@@ -982,7 +983,7 @@ instance (signature ~ (Maybe (GVariant) -> m ()), MonadIO m, IsShortcut a) => O.
 instance O.OverloadedMethodInfo ShortcutSetArgumentsMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutSetArguments",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetArguments"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetArguments"
         })
 
 
@@ -1066,7 +1067,7 @@ instance (signature ~ (Maybe (b) -> m ()), MonadIO m, IsShortcut a, Gtk.Shortcut
 instance O.OverloadedMethodInfo ShortcutSetTriggerMethodInfo a where
     overloadedMethodInfo = P.Just (O.ResolvedSymbolInfo {
         O.resolvedSymbolName = "GI.Gtk.Objects.Shortcut.shortcutSetTrigger",
-        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.9/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetTrigger"
+        O.resolvedSymbolURL = "https://hackage.haskell.org/package/gi-gtk-4.0.11/docs/GI-Gtk-Objects-Shortcut.html#v:shortcutSetTrigger"
         })
 
 
